From f73b655466092169abac34833fb628fce1fcdebe Mon Sep 17 00:00:00 2001
From: jcduff <jcduff@localhost>
Date: Thu, 23 Oct 2008 14:04:24 +0000
Subject: [PATCH] The commit will bring the following features : - An updated version of the underlying database. BDB JE 3.3 is now used. - Attribute API refactoring providing a better abstraction and offering improved performances. - A new GUI called the Control-Panel to replace the Status-Panel: the specifications for this GUI are available on OpenDS Wiki and contains a link to a mockup. See <https://www.opends.org/wiki/page/ControlPanelUISpecification>. - Some changes in the replication protocol to implement "Assured Replication Mode". The specifications are on OpenDS Wiki at <https://www.opends.org/wiki/page/AssuredMode> and section 7 described some of the replication changes required to support this. Assured Replication is not finished, but the main replication protocol changes to support it are done. As explained by Gilles on an email on the Dev mailing list (http://markmail.org/message/46rgo3meq3vriy4a), with these changes the newer versions of OpenDS may not be able to replicate with OpenDS 1.0 instances. - Support for Service Tags on the platforms where the functionality is available and enabled. Specifications are published at <https://www.opends.org/wiki/page/OpenDSServiceTagEnabled>. For more information on Service Tags see <http://wikis.sun.com/display/ServiceTag/Sun+Service+Tag+FAQ>. - The Admin Connector service. In order to provide agentry of the OpenDS server at any time, a new service has been added, dedicated to the administration, configuration and monitoring of the server. An overview of the Admin Connector service and it's use is available on the OpenDS wiki <https://www.opends.org/wiki/page/ManagingAdministrationTrafficToTheServer> - Updates to the various command line tools to support the Admin Connector service. - Some internal re-architecting of the server to put the foundation of future developments such as virtual directory services. The new NetworkGroups and WorkFlow internal services which have been specified in <https://www.opends.org/wiki/page/BasicOperationRoutingThroughNetworkGroup> are now implemented. - Many bug fixes...
---
opends/tests/unit-tests-testng/src/server/org/opends/server/replication/plugin/IsolationTest.java | 64 ++-----------------------------
1 files changed, 5 insertions(+), 59 deletions(-)
diff --git a/opends/tests/unit-tests-testng/src/server/org/opends/server/replication/plugin/IsolationTest.java b/opends/tests/unit-tests-testng/src/server/org/opends/server/replication/plugin/IsolationTest.java
index 4d9c70d..611257d 100644
--- a/opends/tests/unit-tests-testng/src/server/org/opends/server/replication/plugin/IsolationTest.java
+++ b/opends/tests/unit-tests-testng/src/server/org/opends/server/replication/plugin/IsolationTest.java
@@ -48,6 +48,7 @@
import org.opends.server.types.DN;
import org.opends.server.types.ResultCode;
import org.testng.annotations.Test;
+import static org.opends.server.TestCaseUtils.*;
/**
* Test behavior of an LDAP server that is not able to connect
@@ -55,8 +56,6 @@
*/
public class IsolationTest extends ReplicationTestCase
{
- private static final String BASEDN_STRING = "dc=example,dc=com";
-
/**
* Check that the server correctly accept or reject updates when
* the replication is configured but could not connect to
@@ -67,15 +66,13 @@
public void noUpdateIsolationPolicyTest() throws Exception
{
ReplicationDomain domain = null;
- DN baseDn = DN.decode(BASEDN_STRING);
+ DN baseDn = DN.decode(TEST_ROOT_DN_STRING);
SynchronizationProvider replicationPlugin = null;
short serverId = 1;
- cleanDB();
-
try
{
// configure and start replication of dc=example,dc=com on the server
// using a replication server that is not started
replicationPlugin = new MultimasterReplication();
DirectoryServer.registerSynchronizationProvider(replicationPlugin);
@@ -91,7 +88,7 @@
domainConf.setHeartbeatInterval(100000);
domain = MultimasterReplication.createNewDomain(domainConf);
- // check that the udates fail with the unwilling to perform error.
+ // check that the updates fail with the unwilling to perform error.
InternalClientConnection conn =
InternalClientConnection.getRootConnection();
ModifyOperation op =
@@ -108,7 +105,7 @@
// try a new modify operation on the base entry.
op = conn.processModify(baseDn, generatemods("description", "test"));
- // check that the operation was successfull.
+ // check that the operation was successful.
assertEquals(op.getResultCode(), ResultCode.SUCCESS,
op.getAdditionalLogMessage().toString());
}
@@ -124,55 +121,4 @@
}
}
}
-
- /**
- * Clean the database and replace with a single entry.
- *
- * @throws FileNotFoundException
- * @throws IOException
- * @throws Exception
- */
- private void cleanDB() throws FileNotFoundException, IOException, Exception
- {
- String baseentryldif =
- "dn:" + BASEDN_STRING + "\n"
- + "objectClass: top\n"
- + "objectClass: domain\n"
- + "dc: example\n"
- + "entryuuid: " + stringUID(1) + "\n";
-
-
- // Initialization :
- // Load the database with a single entry :
- String buildRoot = System.getProperty(TestCaseUtils.PROPERTY_BUILD_ROOT);
- String path = buildRoot + File.separator + "build" +
- File.separator + "unit-tests" + File.separator +
- "package-instance" + File.separator +
- "addModDelDependencyTest";
- OutputStream out = new FileOutputStream(new File(path));
- out.write(baseentryldif.getBytes());
-
- task("dn: ds-task-id=" + UUID.randomUUID()
- + ",cn=Scheduled Tasks,cn=Tasks\n"
- + "objectclass: top\n"
- + "objectclass: ds-task\n"
- + "objectclass: ds-task-import\n"
- + "ds-task-class-name: org.opends.server.tasks.ImportTask\n"
- + "ds-task-import-backend-id: userRoot\n"
- + "ds-task-import-ldif-file: " + path + "\n"
- + "ds-task-import-reject-file: " + path + "reject\n");
- }
-
-
- /**
- * Builds and return a uuid from an integer.
- * This methods assume that unique integers are used and does not make any
- * unicity checks. It is only responsible for generating a uid with a
- * correct syntax.
- */
- private String stringUID(int i)
- {
- return String.format("11111111-1111-1111-1111-%012x", i);
- }
-
}
@@ -67,15 +66,13 @@
try
{
- // configure and start replication of dc=example,dc=com on the server
+ // configure and start replication of TEST_ROOT_DN_STRING on the server
// using a replication server that is not started
replicationPlugin = new MultimasterReplication();
--
Gitblit v1.10.0